@@ -18,7 +18,7 @@ from watchdog.observers import Observer
 from watchdog.events import FileSystemEventHandler
 
 
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 
 
 class _WatchdogHandler(FileSystemEventHandler):
@@ -86,13 +86,16 @@ class SphinxBuilder(object):
         sys.stdout.write('\n')
         subprocess.Popen(['sphinx-build'] + self._args, stdout=slave)
         os.close(slave)
-        while 1:
-            line = stdout.readline()
-            if not line:
-                break
-            sys.stdout.write('| ')
-            sys.stdout.write(line.rstrip())
-            sys.stdout.write('\n')
+        try:
+            while 1:
+                line = stdout.readline()
+                if not line:
+                    break
+                sys.stdout.write('| ')
+                sys.stdout.write(line.rstrip())
+                sys.stdout.write('\n')
+        except IOError:
+            pass
         sys.stdout.write('+')
         sys.stdout.write('-' * 80)
         sys.stdout.write('\n\n')
